@@ -686,6 +686,14 @@ static PropertyPair valueToQml(const QSSGSceneDesc::Node &target, const QSSGScen
                                                                     + QString::number(quat.y()) + QLatin1String(", ")
                                                                     + QString::number(quat.z()) + QLatin1Char(')') };
         }
+        case QMetaType::QMatrix4x4: {
+            const auto &mat44 = *reinterpret_cast<QMatrix4x4 *>(value.dptr);
+            return { property.name, QLatin1String("Qt.matrix4x4(")
+                        + QString::number(mat44(0, 0)) + u", " + QString::number(mat44(0, 1)) + u", " + QString::number(mat44(0, 2)) + u", " + QString::number(mat44(0, 3)) + u", "
+                        + QString::number(mat44(1, 0)) + u", " + QString::number(mat44(1, 1)) + u", " + QString::number(mat44(1, 2)) + u", " + QString::number(mat44(1, 3)) + u", "
+                        + QString::number(mat44(2, 0)) + u", " + QString::number(mat44(2, 1)) + u", " + QString::number(mat44(2, 2)) + u", " + QString::number(mat44(2, 3)) + u", "
+                        + QString::number(mat44(3, 0)) + u", " + QString::number(mat44(3, 1)) + u", " + QString::number(mat44(3, 2)) + u", " + QString::number(mat44(3, 3)) + u')' };
+        }
         case QMetaType::QUrl:
             return { property.name, QString(QLatin1String("\"%1\"")).arg(asString(value)) };
         case QMetaType::Float:
@@ -1276,7 +1284,7 @@ void writeQml(const QSSGSceneDesc::Scene &scene, QTextStream &stream, const QDir
     indent(output) << blockEnd(output);
 }
 
-void createTimelineAnimation(const QSSGSceneDesc::Animation &anim, QObject *parent, bool useBinaryKeyframes)
+void createTimelineAnimation(const QSSGSceneDesc::Animation &anim, QObject *parent, bool isEnabled, bool useBinaryKeyframes)
 {
 #ifdef QT_QUICK3D_ENABLE_RT_ANIMATIONS
     auto timeline = new QQuickTimeline(parent);
@@ -1305,7 +1313,7 @@ void createTimelineAnimation(const QSSGSceneDesc::Animation &anim, QObject *pare
         timelineKeyframeGroup.append(&timelineKeyframeGroup, keyframeGroup);
     }
     timeline->setEndFrame(anim.length);
-    timeline->setEnabled(true);
+    timeline->setEnabled(isEnabled);
 
     auto timelineAnimation = new QQuickTimelineAnimation(timeline);
     timelineAnimation->setDuration(int(anim.length));
@@ -1320,6 +1328,7 @@ void createTimelineAnimation(const QSSGSceneDesc::Animation &anim, QObject *pare
 #else // QT_QUICK3D_ENABLE_RT_ANIMATIONS
     Q_UNUSED(anim)
     Q_UNUSED(parent)
+    Q_UNUSED(isEnabled)
     Q_UNUSED(useBinaryKeyframes)
 #endif // QT_QUICK3D_ENABLE_RT_ANIMATIONS
 }
